class AlbumsController < ApplicationController
  include TenantLoader
  before_filter :load_tenant
  before_filter :load_gallery
  before_filter :load_album, :except => [:index, :create, :new]

  def index
    @title = "Albums Index Page"
    @albums = @tenant.albums
    render_template
  end

  def show
    @title = "Album Show Page"
    @images = @album.images.recent.paginate(:page => params[:page], :per_page => Image.per_page)
    @facebook_enabled = true
    render_template
  end

  def destroy
    if @album.delete
      flash[:notice] = "Album is deleted successfully"
      redirect_to tenant_gallery_path(@tenant.id, @gallery.id)
    else
      flash[:error] = "Fail to delete album"
      redirect_to tenant_gallery_album_path(@tenant.id, @gallery.id, @album.id)
    end
  end

  def edit
    @title = "Edit Album"
  end

  def new
    @title = "Create New Album"
    @album = @gallery.albums.build
    render_template
  end

  def create
    @album = @gallery.albums.build(params[:album])
    @album.tenant = @tenant
    if @album.save
      flash[:notice] = "New album created successfully"
      redirect_to tenant_gallery_album_path(@tenant.id, @gallery.id, @album.id)
    else
      flash[:error] = "Fail to create new album"
      redirect_to new_tenant_gallery_album_path(@tenant.id, @gallery.id, @album.id)
    end
  end

  def update
    if @album.update_attributes(params[:album])
      flash[:notice] = "Album is updated successfully"
      redirect_to tenant_gallery_album_path(@tenant, @gallery, @album)
    else
      flash[:error]  = "Fail to update album"
      redirect_to edit_gallery_album_path(@tenant, @gallery, @album)
    end
  end

  protected

  def load_gallery
    @gallery = @tenant.galleries.find_by_id(params[:gallery_id])
    raise ActiveRecord::RecordNotFound if @gallery.nil?
  end

  def load_album
    @album = @gallery.albums.find_by_id(params[:id])
    raise ActiveRecord::RecordNotFound if @album.nil?
  end
end