class GalleriesController < ApplicationController
  include TenantLoader
  before_filter :load_tenant
  before_filter :load_gallery, :only => [:show, :edit, :update, :destroy]
  before_filter :check_manage_permission, :only => [:new, :edit, :create, :update, :destroy]

  def index
    @title = "Galleries Index Page"
    @galleries = @tenant.galleries.paginate(:page => params[:page], :per_page => Gallery.per_page)
    render_template
  end

  def show
    @title = "Galleries Show Page"
    @albums = @gallery.albums.recent.paginate(:page => params[:page], :per_page => Album.per_page)
    render_template
  end

  def new
    @title = "Create New Gallery"
    @gallery = @tenant.galleries.build
    render_template
  end

  def create
    @gallery = @tenant.galleries.build(params[:gallery])
    if @gallery.save
      @gallery.reload
      flash[:notice] = 'New Gallery created'
      redirect_to tenant_gallery_path(@tenant.id,@gallery.id)
    else
      flash[:error] = "Some problems had occoured. Please try again later"
      redirect_to new_tenant_gallery_path(@tenant.id)
    end
  end

  def edit
    @title = "Gallery Edit Page"
  end

  def update
    if @gallery.update_attributes(params[:gallery] || {})
      @gallery.reload
      flash[:notice] = "Gallery updated"
      redirect_to tenant_gallery_path(@tenant,@gallery)
    else
      flash[:error] = "Some problems had occoured. Please try again later"
      redirect_to edit_tenant_gallery_path
    end
  end

  def destroy
    if @gallery.destroy
      flash[:notice] = "Gallery destroyed"
      redirect_to tenant_galleries_path
    else
      flash[:error] = "Some problems had occoured. Please try again later"
      redirect_to tenant_gallery_path(@tenant, @gallery)
    end
  end

  protected

  def load_gallery
    @gallery = @tenant.galleries.find_by_id params[:id]
    raise ActiveRecord::RecordNotFound if @gallery.nil?
  end

  def resource
    if @gallery.present?
      return @gallery
    else
      return Gallery.new
    end
  end
end