class TenantsController < ApplicationController
  include TenantLoader

  before_filter :load_tenant
  before_filter :check_update_permission, :only => [:admin]

  SUBJECT_TEMPLATE = "New message from client ##name##"

  def show
    @title = "Home Page"
    @thumb_left = @tenant.last_4_images
    @thumb_right = @tenant.last_4_to_8_images
    @photos = []
    @tenant.last_8_images.each do |i|
      @photos << i.input.url(:original)
    end
    render_template
  end

  def guestbook
    @title = "Guestbook"
    render_template
  end

  def admin
    @title = "Admin Page"
    render_template
  end

  def contact
    @title = "Contact Us"
    render_template
  end

  def submit_form
    content = {:name => params[:name], :number => params[:number], :email => params[:email], :message => params[:message]}
    subject = SUBJECT_TEMPLATE.gsub("##name##", params[:name].to_s)
    tenant_email = @tenant.tenant_config.email
    template_path = "themes/#{@tenant.theme}/mail/contact_email"
    ContactMailer.send_email(subject, content, tenant_email, template_path).deliver

    flash[:notice] = "Your message had been sent. We will get back to you shortly"
    redirect_to :action => :contact
  end

  protected

  def load_tenant
    @tenant = Tenant.find_by_id(params[:id])
    raise ActiveRecord::RecordNotFound if @tenant.nil?
  end

  def resource
    @tenant
  end

end