class Tenant < ActiveRecord::Base
  has_and_belongs_to_many :roles
  # Include default devise modules. Others available are:
  # :token_authenticatable, :encryptable, :confirmable, :lockable, :timeoutable and :omniauthable
  devise :database_authenticatable, :registerable, :recoverable, :rememberable, :trackable, :validatable, :lockable

  # Setup accessible (or protected) attributes for your model
  attr_accessible :tenant_name, :email, :password, :password_confirmation, :remember_me , :tenant_name, :theme

  validates_presence_of :theme


  # Relationships
  has_one :tenant_config
  has_many :galleries
  has_many :albums
  has_many :images
  has_many :comments

  def role?(role)
    self.roles.where(:name => role.to_s).present? if role.present?
  end

  def to_param
    part = self.tenant_name.downcase.tr(' ', '_')
    "#{self.id}_#{part}"
  end

  def last_8_images
    self.images.recent.first(8)
  end

  def last_4_images
    self.images.recent.first(4)
  end

  def last_4_to_8_images
    images = last_8_images
    if images.count > 4
      images[4,images.count-1]
    else
      nil
    end
  end
end
