module TenantLoader
  def load_tenant
    @tenant = Tenant.find_by_id(params[:tenant_id])
    raise ActiveRecord::RecordNotFound if @tenant.nil?
  end

  def resource_belong_to_current_tenant?
    load_tenant if @tenant.nil?
    @tenant == current_tenant || admin?
  end

  def admin?
    current_tenant.present? && current_tenant.role?('super_admin')
  end

  def check_manage_permission
    if resource_belong_to_current_tenant?
      authorize! :manage, resource
    else
      raise CanCan::AccessDenied
    end
  end

  def check_update_permission
    if resource_belong_to_current_tenant?
      authorize! :update, resource
    else
      raise CanCan::AccessDenied
    end
  end
end

