require 'spec_helper'

describe AlbumsController do
  describe 'GET index' do
    before do
      Album.destroy_all
      @tenant = get_tenant
      @landscape_gallery = get_landscape_gallery
      @portrait_gallery = Factory(:portrait_gallery)
      4.times do
        Factory(:album, :gallery => @landscape_gallery, :tenant => @tenant)
        Factory(:album, :gallery => @portrait_gallery, :tenant => @tenant)
      end
    end

    def do_request
      get :index, :tenant_id => @tenant.to_param
    end

    it "should show all the albums under the gallery" do
      do_request
      response.should be_successful
      assigns(:title).should == 'Albums Index Page'
      assigns(:albums).to_a.size.should == 8
      response.should have_selector("#albums_index li.album", :count => 8)
    end
  end

  describe 'GET new' do
    before do
      @tenant = get_tenant
    end

    def do_request
      get :new, :tenant_id => @tenant.to_param
    end

    it "should return the create new album page" do
      do_request
      response.should be_successful
      assigns(:title).should == "Create New Album"
    end
  end

  describe "GET edit" do
    before do
      @album = get_singapore_album
    end

    def do_request
      get :edit, :tenant_id => @album.tenant.to_param, :gallery_id => @album.gallery.to_param, :id => @album.to_param
    end

    it "should return the album edit page" do
      do_request
      response.should be_successful
      assigns(:title).should == "Edit Album"
      assigns(:album).should == @album
    end
  end

  describe "GET show" do
    before do
      @album = get_singapore_album
    end

    def do_request
      get :show, :tenant_id => @album.tenant.to_param, :gallery_id => @album.gallery.to_param, :id => @album.to_param
    end

    it "should return the show page" do
      do_request
      response.should be_successful
      assigns(:title).should == "Album Show Page"
      assigns(:album).should == @album
      assigns(:facebook_enabled).should == true;
    end
  end

  describe "POST create" do
    before do
      @gallery = get_landscape_gallery
      @attributes = get_singapore_album.attributes.merge(:gallery_id => @gallery.id)
    end

    def do_request
      post :create, :tenant_id => @gallery.tenant.to_param, :gallery_id => @gallery.to_param, :album => @attributes
    end

    it "should create a new album and redirect to album show page" do
      expect{
        do_request
      }.to change(Album, :count).by(1)
    end
  end

  describe "PUT update" do
    before do
      @album = get_singapore_album
      @attributes = @album.attributes.merge(:name => "USA Album")
    end

    def do_request
      put :update, :tenant_id => @album.tenant.to_param, :gallery_id => @album.gallery.to_param, :id => @album.to_param, :album => @attributes
    end

    it "should update the album with new name and redirect to album show page" do
      do_request
      @album.reload.name.should == "USA Album"
      response.should redirect_to tenant_gallery_album_path(@album.tenant, @album.gallery, @album)
    end
  end

  describe "DELETE destroy" do
    before do
      @album = get_singapore_album
    end

    def do_request
      delete :destroy, :tenant_id => @album.tenant.to_param, :gallery_id => @album.gallery.to_param, :id => @album.to_param
    end

    it "should destroy the album and redirect to the gallery index page" do
      expect{
        do_request
      }.to change(Album, :count).by(-1)
    end
  end
end