require 'spec_helper'

describe Album do
  describe 'validation' do
    it {should validate_presence_of(:name)}
    it {should validate_presence_of(:tenant_id)}
    it {should validate_presence_of(:gallery_id)}
  end

  describe 'relationships' do
    it {should belong_to(:gallery)}
    it {should belong_to(:tenant)}
    it {should have_many(:images)}
  end

  describe 'recent' do
    before do
      tenant = get_tenant
      @gallery = get_landscape_gallery
      @gallery.albums.destroy_all
      Timecop.freeze(3.days.ago) {@album1 = Factory(:album, :gallery => @gallery, :tenant => tenant)}
      Timecop.freeze(2.days.ago) {@album2 = Factory(:album, :gallery => @gallery, :tenant => tenant)}
      Timecop.freeze(1.day.ago)  {@album3 = Factory(:album, :gallery => @gallery, :tenant => tenant)}
    end

    it "should return the list base on the most recent created at" do
       @gallery.albums.recent.to_a.should == [@album3, @album2, @album1]
    end
  end
end